Installation
=============================

Gini Bank SDK can either be installed by using Swift Package Manager or by manually dragging the required files to your project.

## Swift Package Manager

The [Swift Package Manager](https://swift.org/package-manager/)  is a tool for managing the distribution of Swift code.
Once you have your Swift package set up, adding `GiniBankSDK` as a dependency is as easy as adding it to the dependencies value of your `Package.swift`

```swift
dependencies: [
    .package(url: "https://github.com/gini/bank-sdk-ios.git", .exact("1.11.1"))
]
```
**Note: Availible from iOS 12**
In case that you want to use the certificate pinning in the library, add `GiniBankSDKPinning`:
```swift
dependencies: [
    .package(url: "https://github.com/gini/bank-sdk-pinning-ios.git", .exact("1.11.1"))
]
```

## Manually

If you prefer not to use a dependency management tool, you can integrate the Gini Bank SDK into your project manually.
To do so drop the [GiniBankSDK](https://github.com/gini/gini-mobile-ios/tree/main/BankSDK/GiniBankSDK) (classes and assets) folder into your project as well as its dependant libraries:
- [GiniCaptureSDK](https://github.com/gini/gini-mobile-ios/tree/main/CaptureSDK/GiniCaptureSDK)
- [GiniBankAPILibrary](https://github.com/gini/gini-mobile-ios/tree/main/BankAPILibrary/GiniBankAPILibrary) 
and add the files to your target.

For manual installation [GiniBankSDKPinning](https://github.com/gini/gini-mobile-ios/tree/main/BankSDK/GiniBankSDKPinning) you need to copy the sources and assets of its dependencies:
- [GiniBankSDK](https://github.com/gini/gini-mobile-ios/tree/main/BankSDK/GiniBankSDK)
- [GiniCaptureSDKPinning](https://github.com/gini/gini-mobile-ios/tree/main/CaptureSDK/GiniCaptureSDKPinning)
- [GiniCaptureSDK](https://github.com/gini/gini-mobile-ios/tree/main/CaptureSDK/GiniCaptureSDK)
- [GiniBankAPILibraryPinning](https://github.com/gini/gini-mobile-ios/tree/main/BankAPILibrary/GiniBankAPILibraryPinning) 
- [GiniBankAPILibrary](https://github.com/gini/gini-mobile-ios/tree/main/BankAPILibrary/GiniBankAPILibrary)

You can find the list of dependencies [here](https://github.com/gini/gini-mobile-ios/blob/main/BankSDK/GiniBankSDKPinning/Package.swift).

Xcode will automatically check your project for swift files and will create an autogenerated import header for you.
Use this header in an Objective-C project by adding

```Obj-C
#import "YourProjectName-Swift.h"
```

to your implementation or header files. Note that spaces in your project name result in underscores. So `Your Project` becomes `Your_Project-Swift.h`.
